@@ -247,15 +247,16 @@ divMigrate <- function(infile = NULL, outfile = NULL, boots = 0, stat = "all",
     #source("R/bsFun.R")
     # run bootstrap function
     if(para){
-      library(parallel)
-      cl <- makeCluster(detectCores())
-      clusterExport(cl, c("bsFun", "dat", "pw", "stat"), 
-                    envir = environment())
-      bsStat <- parLapply(cl, idx, function(x){
+      
+      cl <- parallel::makeCluster(detectCores())
+      parallel::clusterExport(cl, c("bsFun", "dat", "pw", "stat"), 
+                              envir = environment())
+      bsStat <- parallel::parLapply(cl, idx, function(x){
         return(bsFun(genos = dat$genos, idx = x, af = dat$af, pw = pw,
                      stat = stat))
       })
-      stopCluster(cl)
+      parallel::stopCluster(cl)
+      
     } else {
       bsStat <- lapply(idx, function(x){
         return(bsFun(genos = dat$genos, idx = x, af = dat$af, pw = pw,
@@ -455,6 +456,7 @@ divMigrate <- function(infile = NULL, outfile = NULL, boots = 0, stat = "all",
 bsFun <- function(genos, idx, af, pw, stat){
   nl <- length(af)
   #myTab <- diveRsity:::myTab
+  #pwHt <- diveRsity:::pwHt
   # sub-sample genos ----
   sampleFun <- function(input, idx){
     return(input[idx,,])
@@ -551,12 +553,14 @@ bsFun <- function(genos, idx, af, pw, stat){
     nmRel <- nm/max(nm, na.rm = TRUE)
   }
   if(stat == "d"){
-    list(dRel = dMig)
+    list(dRel = dMig/max(dMig, na.rm = T))
   } else if(stat == "gst"){
-    list(gRel = gMig)
+    list(gRel = gMig/max(gMig, na.rm = T))
   } else if(stat == "Nm"){
-    list(nmRel = nm)
+    list(nmRel = nm/max(nm, na.rm = T))
   } else if(stat == "all"){
-    list(dRel = dMig, gRel = gMig, nmRel = nm)
+    list(dRel = dMig/max(dMig, na.rm = T), 
+         gRel = gMig/max(gMig, na.rm = T), 
+         nmRel = nm/max(nm, na.rm = T))
   }
 }
\ No newline at end of file
